﻿using System;
using System.Collections.ObjectModel;
using System.Configuration;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;

namespace CSSamples.Samples.Layers
{
    public partial class UseGoogleMap : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#E5E3DF"));
                Map1.CurrentExtent = new RectangleShape(-13939426.6371, 6701997.4056, -7812401.86, 2626987.386962);
                Map1.MapUnit = GeographyUnit.Meter;
                Map1.MapTools.OverlaySwitcher.Enabled = true;

                Map1.ZoomLevelSet = CustomZoomlevelSets();

                Map1.MapTools.OverlaySwitcher.Enabled = true;
                Map1.MapTools.MouseCoordinate.Enabled = true;

                GoogleOverlay google = new GoogleOverlay("Google Map");
                google.JavaScriptLibraryUri = new Uri(ConfigurationManager.AppSettings["GoogleUriV3"]);
                google.GoogleMapType = GoogleMapType.Normal;

                ShapeFileFeatureLayer streetLayer = new ShapeFileFeatureLayer(Server.MapPath("~/SampleData/USA/Austin/austinstreets.shp"));
                streetLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.LocalRoad4;
                streetLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                streetLayer.DrawingMarginPercentage = 10;
                Map1.StaticOverlay.Layers.Add("Austin", streetLayer);

                Proj4Projection proj4 = new Proj4Projection();
                proj4.InternalProjectionParametersString = Proj4Projection.GetEpsgParametersString(4326);
                proj4.ExternalProjectionParametersString = Proj4Projection.GetGoogleMapParametersString();
                streetLayer.FeatureSource.Projection = proj4;

                LayerOverlay shapeOverlay = new LayerOverlay("Shape Overlay", false, TileType.SingleTile);
                shapeOverlay.IsBaseOverlay = false;
                shapeOverlay.Layers.Add(streetLayer);
                shapeOverlay.TransitionEffect = TransitionEffect.None;

                Map1.CustomOverlays.Add(google);
                Map1.CustomOverlays.Add(shapeOverlay);

                streetLayer.Open();
                Map1.CurrentExtent = streetLayer.GetBoundingBox();
            }
        }

        private ZoomLevelSet CustomZoomlevelSets()
        {
            ZoomLevelSet myZoomlevelset = new ZoomLevelSet();

            GoogleMapsZoomLevelSet googlezoomlevelsets = new GoogleMapsZoomLevelSet();
            foreach (ZoomLevel item in googlezoomlevelsets.GetZoomLevels())
            {
                myZoomlevelset.CustomZoomLevels.Add(item);
            }

            ZoomLevel zoomlevel21 = new ZoomLevel(myZoomlevelset.GetZoomLevels()[myZoomlevelset.GetZoomLevels().Count - 1].Scale / 2);
            ZoomLevel zoomlevel22 = new ZoomLevel(zoomlevel21.Scale / 2);
            ZoomLevel zoomlevel23 = new ZoomLevel(zoomlevel22.Scale / 2);
            ZoomLevel zoomlevel24 = new ZoomLevel(zoomlevel23.Scale / 2);
            myZoomlevelset.CustomZoomLevels.Add(zoomlevel21);
            myZoomlevelset.CustomZoomLevels.Add(zoomlevel22);
            myZoomlevelset.CustomZoomLevels.Add(zoomlevel23);
            myZoomlevelset.CustomZoomLevels.Add(zoomlevel24);

            return myZoomlevelset;
        }
    }
}
